<script src="https://cdn.staticfile.org/vue/2.6.14/vue.min.js"></script>
<script src="https://cdn.staticfile.org/element-ui/2.15.6/index.min.js"></script>
<script src="https://cdn.staticfile.org/marked/3.0.7/marked.min.js"></script>
<script src="https://cdn.staticfile.org/axios/0.22.0/axios.min.js"></script>
<script src="https://cdn.staticfile.org/FileSaver.js/2.0.5/FileSaver.min.js"></script>
<script src="https://cdn.staticfile.org/highlight.js/11.2.0/highlight.min.js"></script>
<script src="https://cdn.staticfile.org/js-sha1/0.6.0/sha1.min.js"></script>
<script src="https://cdn.staticfile.org/js-sha256/0.9.0/sha256.min.js"></script>